"""
User interface components for the audio editor application.
"""
from .audio_widgets import (
    WaveformDisplay,
    SpectrogramDisplay,
    AudioInfoPanel,
    TransportControls,
    FilterPanel,
    AnnotationPanel,
    FileOperationsPanel,
    StatusBar,
    ProgressDisplay
)

__all__ = [
    "WaveformDisplay",
    "SpectrogramDisplay", 
    "AudioInfoPanel",
    "TransportControls",
    "FilterPanel",
    "AnnotationPanel",
    "FileOperationsPanel",
    "StatusBar",
    "ProgressDisplay"
]